dm: treewide: Rename ..._platdata variables to just ..._plat

Try to maintain some consistency between these variables by using _plat as
a suffix for them.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/drivers/i2c/omap24xx_i2c.c b/drivers/i2c/omap24xx_i2c.c
index 322d721..1355dc2 100644
--- a/drivers/i2c/omap24xx_i2c.c
+++ b/drivers/i2c/omap24xx_i2c.c
@@ -1049,7 +1049,7 @@
 static int omap_i2c_probe(struct udevice *bus)
 {
 	struct omap_i2c *priv = dev_get_priv(bus);
-	struct omap_i2c_platdata *plat = dev_get_plat(bus);
+	struct omap_i2c_plat *plat = dev_get_plat(bus);
 
 	priv->speed = plat->speed;
 	priv->regs = map_physmem(plat->base, sizeof(void *),
@@ -1065,7 +1065,7 @@
 #if CONFIG_IS_ENABLED(OF_CONTROL) && !CONFIG_IS_ENABLED(OF_PLATDATA)
 static int omap_i2c_of_to_plat(struct udevice *bus)
 {
-	struct omap_i2c_platdata *plat = dev_get_plat(bus);
+	struct omap_i2c_plat *plat = dev_get_plat(bus);
 
 	plat->base = dev_read_addr(bus);
 	plat->speed = dev_read_u32_default(bus, "clock-frequency",
@@ -1094,7 +1094,7 @@
 #if CONFIG_IS_ENABLED(OF_CONTROL) && !CONFIG_IS_ENABLED(OF_PLATDATA)
 	.of_match = omap_i2c_ids,
 	.of_to_plat = omap_i2c_of_to_plat,
-	.plat_auto	= sizeof(struct omap_i2c_platdata),
+	.plat_auto	= sizeof(struct omap_i2c_plat),
 #endif
 	.probe	= omap_i2c_probe,
 	.priv_auto	= sizeof(struct omap_i2c),
diff --git a/drivers/i2c/i2c-emul-uclass.c b/drivers/i2c/i2c-emul-uclass.c
index 4fbf20e..085b824 100644
--- a/drivers/i2c/i2c-emul-uclass.c
+++ b/drivers/i2c/i2c-emul-uclass.c
@@ -14,7 +14,7 @@
  * i2c emulation works using an 'emul' node at the bus level. Each device in
  * that node is in the UCLASS_I2C_EMUL uclass, and emulates one i2c device. A
  * pointer to the device it emulates is in the 'dev' property of the emul device
- * uclass plat (struct i2c_emul_platdata), put there by i2c_emul_find().
+ * uclass plat (struct i2c_emul_plat), put there by i2c_emul_find().
  * When sandbox wants an emulator for a device, it calls i2c_emul_find() which
  * searches for the emulator with the correct address. To find the device for an
  * emulator, call i2c_emul_get_device().
@@ -24,27 +24,27 @@
  */
 
 /**
  * struct i2c_emul_uc_platdata - information about the emulator for this device
  *
  * This is used by devices in UCLASS_I2C_EMUL to record information about the
  * device being emulated. It is accessible with dev_get_uclass_plat()
  *
  * @dev: Device being emulated
  */
-struct i2c_emul_uc_platdata {
+struct i2c_emul_uc_plat {
 	struct udevice *dev;
 };
 
 struct udevice *i2c_emul_get_device(struct udevice *emul)
 {
-	struct i2c_emul_uc_platdata *uc_plat = dev_get_uclass_plat(emul);
+	struct i2c_emul_uc_plat *uc_plat = dev_get_uclass_plat(emul);
 
 	return uc_plat->dev;
 }
 
 int i2c_emul_find(struct udevice *dev, struct udevice **emulp)
 {
-	struct i2c_emul_uc_platdata *uc_plat;
+	struct i2c_emul_uc_plat *uc_plat;
 	struct udevice *emul;
 	int ret;
 
@@ -64,7 +64,7 @@
 UCLASS_DRIVER(i2c_emul) = {
 	.id		= UCLASS_I2C_EMUL,
 	.name		= "i2c_emul",
-	.per_device_plat_auto	= sizeof(struct i2c_emul_uc_platdata),
+	.per_device_plat_auto	= sizeof(struct i2c_emul_uc_plat),
 };
 
 /*
@@ -24,27 +24,27 @@
 
 /**
- * struct i2c_emul_uc_platdata - information about the emulator for this device
+ * struct i2c_emul_uc_plat - information about the emulator for this device
  *
  * This is used by devices in UCLASS_I2C_EMUL to record information about the